@@ -4,19 +4,21 @@ import json
 from unittest import mock
 from gitlabber import gitlab_tree
 
-URL = "http://dummy"
+URL = "http://gitlab.my.com/"
 TOKEN = "MOCK_TOKEN"
-GROUP_URL = "http://gitlab.my.com/group1"
-GROUP_NAME = "group1"
+GROUP_URL = "http://gitlab.my.com/group"
+GROUP_NAME = "group"
 
-SUBGROUP_URL = "http://gitlab.my.com/group1/subgroup1"
-SUBGROUP_NAME = "subgroup1"
+SUBGROUP_URL = "http://gitlab.my.com/group/subgroup"
+SUBGROUP_NAME = "subgroup"
 
-PROJECT_URL = "http://gitlab.my.com/group1/subgroup1/project1/project1.git"
-PROJECT_NAME = "project1"
+PROJECT_URL = "http://gitlab.my.com/group/subgroup/project/project.git"
+PROJECT_NAME = "project"
 
+YAML_TEST_INPUT_FILE = "tests/test-input.yaml"
 YAML_TEST_OUTPUT_FILE = "tests/test-output.yaml"
 JSON_TEST_OUTPUT_FILE = "tests/test-output.json"
+TREE_TEST_OUTPUT_FILE = "tests/test-output.tree"
 
 class MockNode:
     def __init__(self, id, name, url, subgroups=mock.MagicMock(), projects=mock.MagicMock()):
@@ -25,6 +27,7 @@ class MockNode:
         self.url = url
         self.web_url = url
         self.ssh_url_to_repo = url
+        self.http_url_to_repo = url
         self.subgroups = subgroups
         self.projects = projects
 
@@ -47,7 +50,7 @@ class Listable:
 def validate_root(root):
     assert root.is_leaf is False
     assert root.name == ""
-    assert root.url == "http://dummy"
+    assert root.url == "http://gitlab.my.com/"
     assert len(root.children) == 1
     assert root.height == 3
 
@@ -84,7 +87,7 @@ def validate_tree(root):
 
 def create_test_gitlab(monkeypatch, includes=None, excludes=None, in_file=None):
     gl = gitlab_tree.GitlabTree(
-        URL, TOKEN, includes=includes, excludes=excludes, in_file=in_file)
+        URL, TOKEN, "ssh", includes=includes, excludes=excludes, in_file=in_file)
     projects = Listable(MockNode(2, PROJECT_NAME, PROJECT_URL))
     subgroup_node = MockNode(2, SUBGROUP_NAME, SUBGROUP_URL, projects=projects)
     subgroups = Listable(subgroup_node)
