@@ -4,6 +4,7 @@ from gitlabber import __version__ as VERSION
 import tests.output_test_utils as output_util
 
 from gitlabber.format import PrintFormat
+from gitlabber.method import CloneMethod
 from unittest import mock
 from anytree import Node
 import pytest
@@ -31,7 +32,7 @@ def test_args_version():
 def test_args_logging(mock_tree, mock_log, mock_os, mock_sys, mock_logging):
     args_mock = mock.Mock()
     args_mock.return_value = Node(
-        name="test", version=None, debug=True, include="", exclude="", url="test_url", token="test_token", file=None, print=None, dest=".")
+        name="test", version=None, verbose=True, include="", exclude="", url="test_url", token="test_token", method=CloneMethod.SSH, file=None, print=None, dest=".")
     cli.parse_args = args_mock
 
     mock_streamhandler = mock.Mock()
@@ -52,7 +53,7 @@ def test_args_include(mock_tree):
     exc_groups = "/exc**,/exc**"
     args_mock = mock.Mock()
     args_mock.return_value = Node(
-        name="test", version=None, debug=None, include=inc_groups, exclude=exc_groups, url="test_url", token="test_token", file=None, print=None, dest=".")
+        name="test", version=None, debug=None, include=inc_groups, exclude=exc_groups, url="test_url", token="test_token", method=CloneMethod.SSH, file=None, print=None, dest=".")
     cli.parse_args = args_mock
     
     split_mock = mock.Mock()
@@ -68,7 +69,7 @@ def test_args_include(mock_tree):
 def test_args_include(mock_tree):
     args_mock = mock.Mock()
     args_mock.return_value = Node(
-        name="test", version=None, debug=None, include="", exclude="", url="test_url", token="test_token", file=None, print=True, dest=".", print_format=PrintFormat.YAML)
+        name="test", version=None, verbose=None, include="", exclude="", url="test_url", token="test_token", method=CloneMethod.SSH, file=None, print=True, dest=".", print_format=PrintFormat.YAML)
     cli.parse_args = args_mock
 
     print_tree_mock = mock.Mock()
@@ -91,7 +92,7 @@ def test_validate_path():
 def test_empty_tree(mock_tree):
     args_mock = mock.Mock()
     args_mock.return_value = Node(
-        name="test", version=None, debug=None, include="", exclude="", url="test_url", token="test_token", file=None, print=True, dest=".")
+        name="test", version=None, verbose=None, include="", exclude="", url="test_url", token="test_token", method=CloneMethod.SSH, file=None, print=True, dest=".")
     cli.parse_args = args_mock
 
     with pytest.raises(SystemExit):
