@@ -53,7 +53,6 @@ def test_is_git_repo_throws():
     with pytest.raises(git.git.exc.NoSuchPathError):
         git.is_git_repo("dummy_dir")
 
-
 @mock.patch('gitlabber.git.git')
 def test_pull_repo(mock_git):
     mock_repo = mock.Mock()
@@ -76,3 +75,32 @@ def test_clone_repo(mock_git):
         Node(name="dummy_url", url="dummy_url"), "dummy_dir")
 
     mock_git.Repo.clone_from.assert_called_once_with("dummy_url", "dummy_dir")
+
+@mock.patch('gitlabber.git.git')
+def test_pull_repo_interrupt(mock_git):
+    mock_repo = mock.Mock()
+    mock_git.Repo = mock_repo
+    git.is_git_repo = mock.MagicMock(return_value=True)
+
+    repo_instance = mock_git.Repo.return_value
+    repo_instance.remotes.origin.pull.side_effect=KeyboardInterrupt('pull test keyboard interrupt')
+
+    with pytest.raises(SystemExit):
+        git.clone_or_pull_project(
+            Node(name="dummy_url", url="dummy_url"), "dummy_dir")
+
+    mock_git.Repo.assert_called_once_with("dummy_dir")
+    repo_instance.remotes.origin.pull.assert_called_once()
+
+@mock.patch('gitlabber.git.git')
+def test_clone_repo_interrupt(mock_git):
+    mock_repo = mock.Mock()
+    mock_git.Repo = mock_repo
+    git.is_git_repo = mock.MagicMock(return_value=False)
+    mock_git.Repo.clone_from.side_effect=KeyboardInterrupt('clone test keyboard interrupt')
+
+    with pytest.raises(SystemExit):
+        git.clone_or_pull_project(
+            Node(name="dummy_url", url="dummy_url"), "dummy_dir")
+
+    mock_git.Repo.clone_from.assert_called_once_with("dummy_url", "dummy_dir")
\ No newline at end of file
